package sun.net.www.protocol.http.ntlm;

import java.util.Base64;
import java.io.IOException;

public class NTLMAuthSequence
{
    private String username;
    private String password;
    private String ntdomain;
    private int state;
    private long crdHandle;
    private long ctxHandle;
    NTLMAuthSequence.Status status;
    
    NTLMAuthSequence(String username, String password, String ntdomain) throws IOException {
        this.username = username;
        this.password = password;
        this.ntdomain = ntdomain;
        this.status = new NTLMAuthSequence.Status();
        this.state = 0;
        this.crdHandle = this.getCredentialsHandle(username, ntdomain, password);
        if (this.crdHandle == 0L) {
            throw new IOException("could not get credentials handle");
        }
        return;
    }
    
    public String getAuthHeader(String src) throws IOException {
        byte[] decode = null;
        assert !this.status.sequenceComplete;
        if (src != null) {
            decode = Base64.getDecoder().decode(src);
        }
        byte[] nextToken = this.getNextToken(this.crdHandle, decode, this.status);
        if (nextToken == null) {
            throw new IOException("Internal authentication error");
        }
        return Base64.getEncoder().encodeToString(nextToken);
    }
    
    public boolean isComplete() {
        return this.status.sequenceComplete;
    }
    
    private static native void initFirst(Class<NTLMAuthSequence.Status> p0);
    
    private native long getCredentialsHandle(String p0, String p1, String p2);
    
    private native byte[] getNextToken(long p0, byte[] p1, NTLMAuthSequence.Status p2);
    
    static {
        initFirst(NTLMAuthSequence.Status.class);
    }
    
    class Status
    {
        boolean sequenceComplete;
    }
}
